==> haskell-infer-license-0.2.0-336-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-6cUObsl5GKs2gpQI0g7wQu
key:                  infer-license-0.2.0-6cUObsl5GKs2gpQI0g7wQu
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  fed840bdd3eac479d2def0f133a58baf
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infer-license
hs-libraries:         HSinfer-license-0.2.0-6cUObsl5GKs2gpQI0g7wQu
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 text-2.0.2
    text-metrics-0.3.3-6UdqDZdYZ7PFq6rJDZ3g3W

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-infer-license-0.2.0-337-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-GiFfTFYs5Kq3yIfTDdPmAl
key:                  infer-license-0.2.0-GiFfTFYs5Kq3yIfTDdPmAl
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  e13867e68a6bb9c13be40fd3f9bdd538
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infer-license
hs-libraries:         HSinfer-license-0.2.0-GiFfTFYs5Kq3yIfTDdPmAl
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 text-2.0.2
    text-metrics-0.3.3-9oL4Y89arAB3kQGZDNbN8q

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
